@@ -9,7 +9,7 @@ from gramex.http import OK, FORBIDDEN, METHOD_NOT_ALLOWED
 from orderedattrdict import AttrDict
 from gramex.ml import r
 from gramex.transforms import badgerfish, rmarkdown
-from nose.tools import ok_
+from nose.tools import ok_, eq_
 from nose.plugins.skip import SkipTest
 from . import server, tempfiles, TestGramex, folder
 
@@ -48,11 +48,11 @@ class TestFileHandler(TestGramex):
             r = self.get(url + '?高=σ&λ=►')
             if check:
                 self.assertTrue(r.url.endswith(url + '/?%E9%AB%98=%CF%83&%CE%BB=%E2%96%BA'))
-                redirect_codes = (301, 302)
                 self.assertIn(r.history[0].status_code, redirect_codes, url)
             else:
                 self.assertEqual(len(r.history), 0)
 
+        redirect_codes = (301, 302)
         self.check('/dir/noindex/', code=404)
         adds_slash('/dir/noindex/subdir', False)
         self.check('/dir/noindex/subdir/', code=404)
@@ -117,6 +117,11 @@ class TestFileHandler(TestGramex):
             'Content-Type': 'image/jpeg'
         })
 
+        r = self.get('/dir/index/subdir', allow_redirects=False, headers={
+            'X-Request-URI': 'https://x.com/a/dir/index/subdir'})
+        ok_(r.status_code in redirect_codes)
+        eq_(r.headers['Location'], 'https://x.com/a/dir/index/subdir/')
+
     def test_args(self):
         self.check('/dir/args/?高=σ', text=json.dumps({'高': ['σ']}))
         self.check('/dir/args/?高=σ&高=λ&س=►', text=json.dumps(
@@ -179,6 +184,16 @@ class TestFileHandler(TestGramex):
         self.check('/dir/transform/template.txt?x=►', text='x – ►')
         self.check('/dir/transform/template.txt?x=λ', text='x – λ')
 
+    def test_sass(self):
+        for dir in ('/dir/transform-sass', '/dir/sass-file'):
+            for file in ('import.scss', 'import.sass'):
+                text = self.check(f'{dir}/{file}?primary=red&color-alpha=purple').text
+                ok_('.ui-import-a{color:red}' in text, f'{dir}.{file}: import a.scss with vars')
+                ok_('--primary: red' in text, f'{dir}.{file}: import bootstrap with vars')
+                ok_('--alpha: purple' in text, f'{dir}.{file}: import gramexui with vars')
+        self.check('/dir/transform-sass/a.scss?primary=blue', text='.ui-import-a{color:blue}')
+        self.check('/dir/transform-sass/b.scss?primary=blue', text='.ui-import-b{color:blue}')
+
     def test_template(self):
         self.check('/dir/template/index-template.txt?arg=►', text='– ►')
         self.check('/dir/template/non-index-template.txt?arg=►', text='– ►')
